===
API
===

This is the documentation for the Python client API for eduVPN.

Remote calls
============

.. automodule:: eduvpn.remote
    :members:
    :undoc-members:
    :show-inheritance:


eduVPN OAuth2
=============

.. automodule:: eduvpn.oauth2
    :members:
    :undoc-members:
    :show-inheritance:


Crypto
======

.. automodule:: eduvpn.crypto
    :members:
    :undoc-members:
    :show-inheritance:


eduVPN Storage
==============

.. automodule:: eduvpn.storage
    :members:
    :undoc-members:
    :show-inheritance:


Utilities
=========

.. automodule:: eduvpn.utils
     :members:
     :undoc-members:
     :show-inheritance:
